@@ -61,6 +61,8 @@ define([
             , VP_BLOCK_BLOCKCODELINETYPE_CLASS_DEF
             , VP_BLOCK_BLOCKCODELINETYPE_CONTROL
             , VP_BLOCK_BLOCKCODELINETYPE_API
+            , VP_BLOCK_BLOCKCODELINETYPE_TEXT
+            , VP_BLOCK_BLOCKCODELINETYPE_NODE
  
             , VP_CLASS_APIBLOCK_BODY 
 
@@ -790,9 +792,10 @@ define([
             /** API 블럭 */
             $(htmlDom).addClass(VP_BLOCK_BLOCKCODELINETYPE_API);
         } else if (blockType == BLOCK_CODELINE_TYPE.TEXT) {
+            $(htmlDom).addClass(VP_BLOCK_BLOCKCODELINETYPE_TEXT);
             $(htmlDom).css(STR_BACKGROUND_COLOR, STR_TRANSPARENT);
         } else if (blockType == BLOCK_CODELINE_TYPE.NODE) {
-        
+            $(htmlDom).addClass(VP_BLOCK_BLOCKCODELINETYPE_NODE);
         } else {
              $(htmlDom).addClass(VP_BLOCK_BLOCKCODELINETYPE_CODE);
         }
