@@ -1,14 +1,11 @@
 define([
     'jquery'
-    , 'nbextensions/visualpython/src/common/vpCommon'
-    , 'nbextensions/visualpython/src/common/constant'
-    , 'nbextensions/visualpython/src/common/StringBuilder'
 
-    , '../../api.js'    
+    , 'nbextensions/visualpython/src/common/StringBuilder'
+  
     , '../../constData.js'
     
-], function ( $, vpCommon, vpConst, sb, 
-              api,  constData ) {
+], function ( $,  sb,  constData ) {
     const             {VP_CLASS_STYLE_FLEX_ROW_CENTER} = constData;
     var MakeOptionInput = function(id, className, value, placeholder) {
         var sbOptionInput = new sb.StringBuilder();
